package com.chelvc.framework.database.support;

import com.baomidou.mybatisplus.core.metadata.TableInfo;
import lombok.NonNull;

/**
 * 批量创建或修改方法实现
 *
 * @author Woody
 * @date 2024/2/27
 */
public class BatchCreateUpdateMethod extends AbstractCreateMethod {
    public BatchCreateUpdateMethod() {
        super("batchCreateUpdate");
    }

    @Override
    protected String initializeMethodScript(@NonNull TableInfo table) {
        String columns = this.getColumns(table);
        String properties = this.getProperties(table, "entity.");
        String updates = "<foreach collection=\"update.expressions.entrySet()\" " +
                "index=\"column\" item=\"value\" separator=\",\">${column}${value}</foreach>";
        return String.format(
                "<script>\nINSERT INTO %s (%s) VALUES\n" +
                        "<foreach collection=\"entities\" item=\"entity\" separator=\",\">(%s)</foreach>\n" +
                        "ON DUPLICATE KEY UPDATE %s\n</script>",
                table.getTableName(), columns, properties, updates
        );
    }
}
