package com.chelvc.framework.security.context;

import java.util.Set;
import java.util.stream.Stream;

import com.chelvc.framework.base.context.ApplicationContextHolder;
import com.chelvc.framework.base.context.Session;
import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.common.util.ObjectUtils;
import lombok.NonNull;

/**
 * 应用安全相关操作上下文工具类
 *
 * @author Woody
 * @date 2024/5/24
 */
public final class SecurityContextHolder {
    /**
     * 默认权限分组
     */
    public static final String DEFAULT_PERMISSION_GROUP = "DEFAULT";

    private SecurityContextHolder() {
    }

    /**
     * 判断当前用户是否拥有任意权限
     *
     * @param permissions 权限标识数组
     * @return true/false
     */
    public static boolean hashAnyPermission(@NonNull String... permissions) {
        if (ObjectUtils.isEmpty(permissions)) {
            return true;
        }
        Session session = SessionContextHolder.getSession(false);
        Set<String> authorities = ObjectUtils.ifNull(session, Session::getAuthorities);
        if (ObjectUtils.notEmpty(authorities)) {
            Stream<String> stream = Stream.of(permissions);
            if (stream.anyMatch(authorities::contains)) {
                return true;
            }
            for (String authority : authorities) {
                Set<?> properties = ApplicationContextHolder.getSafeProperty(authority, Set.class);
                if (ObjectUtils.notEmpty(properties) && stream.anyMatch(properties::contains)) {
                    return true;
                }
            }
        }
        return false;
    }
}
